Version: 0.4
Title: Bayesian Network Modeling and Analysis
Description: A "Shiny"" web application for creating interactive Bayesian Network models, learning the structure and parameters of Bayesian networks, and utilities for classic network analysis.
URL: https://github.com/paulgovan/bayesiannetwork, http://paulgovan.github.io/BayesianNetwork/, https://github.com/paulgovan/BayesianNetwork
BugReports: https://github.com/paulgovan/BayesianNetwork/issues
Depends: R (≥ 3.6.0)
License: Apache License (≥ 2)
Imports: bnlearn, heatmaply, lattice, networkD3, plotly, rintrojs, shiny, shinyAce, shinydashboard, shinyWidgets,
RoxygenNote: 7.3.3
Suggests: chromote, knitr, rmarkdown, testthat (≥ 3.0.0), shinytest2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-23 15:44:59 UTC; paulgovan
Author: Paul Govan ORCID iD [aut, cre, cph]
Maintainer: Paul Govan <paul.govan2@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-23 16:10:14 UTC

BayesianNetwork: Bayesian Network Modeling and Analysis

Description

logo

A "Shiny"" web application for creating interactive Bayesian Network models, learning the structure and parameters of Bayesian networks, and utilities for classic network analysis.

Author(s)

Maintainer: Paul Govan paul.govan2@gmail.com (ORCID) [copyright holder]

See Also

Useful links:


Bayesian Network modeling and analysis.

Description

BayesianNetwork is a Shiny web application for Bayesian Network modeling and analysis.

Usage

BayesianNetwork()

Value

The function returns no value. It launches a shiny web application for Bayesian Network modeling and analysis.

See Also

http://paulgovan.github.io/BayesianNetwork/

Examples

if (interactive()) {
  BayesianNetwork()
}