| Title: | Bayesian Network Modeling and Analysis |
|---|---|
| Description: | A "Shiny"" web application for creating interactive Bayesian Network models, learning the structure and parameters of Bayesian networks, and utilities for classic network analysis. |
| Authors: | Paul Govan [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-1821-8492>) |
| Maintainer: | Paul Govan <[email protected]> |
| License: | Apache License (>= 2) |
| Version: | 0.4 |
| Built: | 2026-05-19 16:57:01 UTC |
| Source: | https://github.com/paulgovan/bayesiannetwork |
BayesianNetwork is a Shiny web application for Bayesian Network modeling and analysis.
BayesianNetwork()BayesianNetwork()
The function returns no value. It launches a shiny web application for Bayesian Network modeling and analysis.
http://paulgovan.github.io/BayesianNetwork/
if (interactive()) { BayesianNetwork() }if (interactive()) { BayesianNetwork() }